@@ -1296,7 +1296,7 @@ found, the current buffer remains selected."
   (let ((r vm-drop-buffer-name-chars))
     (if (eq r t) (setq r "[^\x0-\x80]"))
     (if (and buffer-name r)
-        (replace-in-string buffer-name r "_" t)
+        (vm-replace-in-string buffer-name r "_" t)
       buffer-name)))
 
 ;;;###autoload
